@@ -8,7 +8,7 @@ checkLatinHypercube <- function(X)
     return(FALSE)
   if (any(is.na(X)))
     return(FALSE)
-  # check that the matrix is a latin hypercube
+  # check that the matrix is a Latin hypercube
   g <- function(Y)
   {
     # check that this column contains all the cells
@@ -29,27 +29,23 @@ checkOA <- function(X)
 
 encodeOA <- function(X, n)
 {
-  assertthat::assert_that(n > 1 & is.integer(n),
-                          msg = "n must be an integer > 1")
+  stopifnot(n > 1)
+  stopifnot(is.integer(n))
   if (n == 2)
   {
-    X[which(X == 0, arr.ind = TRUE)] <- -1
-    return(X)
+    # 0, 1 => -1, 1
+    X <- X*2 - 1
   } else if (n == 3)
   {
-    X[which(X == 0, arr.ind = TRUE)] <- -1
-    X[which(X == 1, arr.ind = TRUE)] <- 0
-    X[which(X == 2, arr.ind = TRUE)] <- 1
-    return(X)
+    # 0, 1, 2 => -1, 0, 1
+    X <- X - 1
   } else if (n == 4)
   {
-    X[which(X == 0, arr.ind = TRUE)] <- -1
-    X[which(X == 1, arr.ind = TRUE)] <- -1/3
-    X[which(X == 2, arr.ind = TRUE)] <- 1/3
-    X[which(X == 3, arr.ind = TRUE)] <- 1
-    return(X)
+    # 0, 1, 2, 3 => -1, -1/3, 1/3, 1
+    X <- X * 2 / 3 - 1
   } else if (n > 4)
   {
-    stop("Not implemented yet")
+    X <- X * 2 / (n - 1) - 1
   }
+  return(X)
 }
